import groovyx.gpars.GParsPool
import com.xmatters.migration.DatabaseType

description = 'Perform the entire migration in one step'

schema.alterTableTriggersIndexesAndConstraints(false)
schema.scrubTables()

copyTableColumns('ORGS', ['AUDIT_RETN'], [HOSTNAME_PREFIX: "ORG_ID"])
copyTableColumns('SCENS', ['BYPASS_OUTBOUND_AUTH'])

if (!excludeNodeEngineTables) {
    copyTableColumns('NODES', null, [DEPLOYMENT_STATUS: "NOT_DEPLOYED"])
}
copyTableColumns('ORGS_REV', ['AUDIT_RETN'])
copyTableColumns('SCENS_REV', ['BYPASS_OUTBOUND_AUTH'])

List<String> tables = SYSTEM_TABLES + RECIPIENT_TABLES + REV_REPORTING_TABLES + REV_NOT_REPORTING_TABLES + ARC_TABLES
println "working with a pool size of $POOL_SIZE"
GParsPool.withPool(POOL_SIZE) {
    tables.eachParallel { tableName ->
        copyTableColumns(tableName)
    }
}

if (excludeNodeEngineTables) {
    tables = talbes + ['ORGS', 'SCENS', 'ORGS_REV','SCENS_REV']
} else {
    tables = tables + ['ORGS','SCENS','NODES','ORGS_REV','SCENS_REV']
}

verifyCopy(tables)

/**
 * The 'HUB' node component is not supported in 5.0
 */
runSqlOnTarget("delete from node_components where type = 'HUB';")

// Update permissions with any custom changes from the source system
updateRolesFunctionsPermissions()


adjustSequence('ACTIVITY_UPDATES','ACTIVITY_UPDATES_SEQ','ACTIVITY_UPDATES_ID')
adjustSequence('ADDRESSES','ADDRESSES_SEQ','ADDRESS_ID')
adjustSequence('ALERT_GENERATOR','ALERT_GENERATOR_SEQ','ALERT_GENERATOR_ID')
adjustSequence('ALERT','ALERT_SEQ','ALERT_ID')
adjustSequence('APIA_OUTBOUND_QUEUE','APIA_OUTBOUND_QUEUE_SEQ','APXML_ID')
adjustSequence('APPLICATION','APPLICATION_SEQ','APPLICATION_ID')
adjustSequence('AP_AGNTS','AP_AGNTS_SEQ','AP_AGNT_ID')
adjustSequence('AP_CLNTS','AP_CLNTS_SEQ','AP_CLNT_ID')
adjustSequence('ATTRS','ATTRS_SEQ','ATTR_ID')
adjustSequence('ATTR_CAT','ATTR_CAT_SEQ','ATTR_CAT_ID')
adjustSequence('AUDIT_EVS_ALL','AUDIT_EVS_ALL_SEQ','AUDIT_EV_ID',true,false,true)
adjustSequence('AUDIT_EVS_ALL','AUDIT_EVS_INSERT_ORDER_SEQ','INSERT_ORDER')
adjustSequence('CLUSTERS','CLUSTERS_SEQ','CLUSTER_ID')
adjustSequence('COMM_FLDS','COMM_FLDS_SEQ','COMM_FLD_ID',true,false,true)
adjustSequence('COMM','COMM_SEQ','COMM_ID',true,false,true)
adjustSequence('COMP_CONST','COMP_CONST_ID_SEQ','COMP_CONST_ID')
adjustSequence('CONFERENCES','CONFERENCES_ID_SEQ','ID')
adjustSequence('CONTACT_SESSIONS','CONTACT_SESSIONS_SEQ','SESSION_ID',true,false,true)
adjustSequence('CONTINUATIONS','CONTINUATIONS_SEQ','CONTINUATION_ID',true,false,true)
adjustSequence('COUNTRIES','COUNTRIES_SEQ','COUNTRY_ID')
adjustSequence('CREDS_HISTORY','CREDS_HISTORY_SEQ','CRED_HISTORY_ID')
adjustSequence('CUST_FLDS','CUST_FLDS_SEQ','CUST_FLD_ID')
adjustSequence('CUST_MSG_PNLS','CUST_MSG_PNLS_SEQ','CUST_MSG_PNL_ID')
adjustSequence('CUST_PAGES','CUST_PAGES_SEQ','CUST_PAGE_ID')
adjustSequence('DATA_LOCK','DATA_LOCK_SEQ','DATA_LOCK_ID')
adjustSequence('DATE_RNG','DATE_RNG_SEQ','DATE_RNG_ID')
adjustSequence('DATE_RULES','DATE_RULES_SEQ','DATE_RULE_ID')
adjustSequence('DVC_NAMES','DVC_NAMES_SEQ','DVC_NAME_ID')
adjustSequence('DVC_TF','DVC_TF_SEQ','DVC_TF_ID')
adjustSequence('ENH_MSGS','ENH_MSGS_SEQ','ENH_MSG_ID',true,false,true)
adjustSequence('ENH_MSG_MONITORS','ENH_MSG_MONITORS_SEQ','ENH_MSG_MONITOR_ID',true,false,true)
adjustSequence('ENH_MSG_PREDS','ENH_MSG_PREDS_SEQ','ENH_MSG_PRED_ID',true,false,true)
adjustSequence('ENH_MSG_PRED_VALUES','ENH_MSG_PRED_VALUES_SEQ','ENH_MSG_PRED_VALUE_ID',true,false,true)
adjustSequence('ENH_MSG_RECIPIENTS','ENH_MSG_RECIPIENTS_SEQ','ENH_MSG_RECIPIENT_ID',true,false,true)
adjustSequence('ENH_MSG_RESPONSES','ENH_MSG_RESPONSES_SEQ','ENH_MSG_RESPONSE_ID',true,false,true)
adjustSequence('EPIC_UPLOADS','EPIC_UPLOADS_ID_SEQ','ID')
adjustSequence('EVS_REPORTSTATUS','EVS_REPORTSTATUS_ID_SEQ','ID')
adjustSequence('EVS','EVS_SEQ','EV_ID',true,false,true)
adjustSequence('EVS_TML','EVS_TML_SEQ','EV_TML_ID')
adjustSequence('EV_DMN_CONST','EV_DMN_CONST_ID_SEQ','EV_DMN_CONST_ID')
adjustSequence('EV_DMN_PRED','EV_DMN_PRED_SEQ','PRED_ID')
adjustSequence('EV_DMN_PRED_VALUES','EV_DMN_PRED_VALUES_SEQ','PRED_VALUE_ID')
adjustSequence('EV_DMN','EV_DMN_SEQ','EV_DMN_ID')
adjustSequence('EXT_USER_SESSION','EXT_USER_SESSION_SEQ','USER_SESSION_ID')
adjustSequence('FAST_ACCESS_SCENS','FAST_ACCESS_SCENS_SEQ','FAST_ACCESS_SCEN_ID')
adjustSequence('FUNC','FUNC_SEQ','FUNC_ID')
adjustSequence('GLB_CONST','GLB_CONST_ID_SEQ','GLB_CONST_ID')
adjustSequence('GLB_PIN','GLB_PIN_SEQ','GLB_PIN_ID',true,false,true)
adjustSequence('GRP_TF','GRP_TF_SEQ','GRP_TF_ID')
adjustSequence('HOLIDAYS','HOLIDAYS_SEQ','HOLIDAY_ID')
adjustSequence('IMPORT_ERROR','IMPORT_ERROR_ID_SEQ','ERROR_ID')
adjustSequence('IMPORT_JOB','IMPORT_JOB_ID_SEQ','JOB_ID')
adjustSequence('INTR_AGNTS','INTR_AGNTS_SEQ','INTR_AGNT_ID')
adjustSequence('INTR_SVCS','INTR_SVCS_SEQ','INTR_SVC_ID')
adjustSequence('LANGUAGES','LANGUAGES_SEQ','LANGUAGE_ID')
adjustSequence('MESSAGE_PANEL','MESSAGE_PANEL_SEQ','MESSAGE_PANEL_ID')
adjustSequence('MSG_BUS_MSGS','MSG_BUS_MSGS_SEQ','MSG_ID',true,false,true)
adjustSequence('MSG_BUS_STAT','MSG_BUS_STAT_ID_SEQ','MSG_BUS_STAT_ID')
adjustSequence('MSG_DMN_PREDS','MSG_DMN_PREDS_SEQ','MSG_DMN_PRED_ID')
adjustSequence('MSG_DMN','MSG_DMN_SEQ','MSG_DMN_ID')
adjustSequence('MSG_TOKEN_LIVE_NTFN','MSG_TOKEN_LIVE_NTFN_SEQ','MSG_TOKEN_LIVE_NTFN_ID')
if(!excludeNodeEngineTables) {
    adjustSequence('NODES','NODES_SEQ','NODE_ID')
    adjustSequence('NODE_COMPONENTS','NODE_COMPONENTS_SEQ','NODE_COMPONENT_ID')
    adjustSequence('NODE_MONS','NODE_MONS_SEQ','NODE_MON_ID')
    adjustSequence('NODE_PP_MONS','NODE_PP_MONS_SEQ','NODE_PP_MON_ID')
}
adjustSequence('NTFN_EVS','NTFN_EVS_SEQ','EV_ID',true,false,true)
adjustSequence('NTFN_RESPONSES','NTFN_RESPONSES_SEQ','NTFN_RESPONSE_ID',true,false,true)
adjustSequence('NTFN','NTFN_SEQ','NTFN_ID',true,false,true)
adjustSequence('ORGS','ORGS_SEQ','ORG_ID')
adjustSequence('ORG_CLUSTERS','ORG_CLUSTERS_SEQ','ORG_CLUSTER_ID')
adjustSequence('ORG_DVC_NAMES','ORG_DVC_NAMES_SEQ','ORG_DVC_NAME_ID')
adjustSequence('ORG_FUNC','ORG_FUNC_SEQ','ORG_FUNC_ID')
adjustSequence('ORG_HOLIDAYS','ORG_HOLIDAYS_SEQ','ORG_HOLIDAY_ID')
adjustSequence('ORG_LANGUAGES','ORG_LANGUAGES_SEQ','ORG_LANGUAGE_ID')
adjustSequence('ORG_LDAPS','ORG_LDAPS_SEQ','ORG_LDAP_ID')
adjustSequence('ORG_LDAP_SERVER','ORG_LDAP_SERVER_ID_SEQ','ORG_LDAP_SERVER_ID')
adjustSequence('ORG_LDAP_TMPLS','ORG_LDAP_TMPLS_SEQ','ORG_LDAP_DOMAIN_ID')
adjustSequence('ORG_PWD_POLICIES','ORG_PWD_POLICIES_SEQ','ORG_PP_ID')
adjustSequence('ORG_QUOTAS','ORG_QUOTAS_SEQ','ORG_QUOTA_ID')
adjustSequence('ORG_SVC_PROVS','ORG_SVC_PROVS_SEQ','ORG_SVC_PROV_ID')
adjustSequence('ORG_TZ','ORG_TZ_SEQ','ORG_TZ_ID')
adjustSequence('PANEL_SECTION','PANEL_SECTION_SEQ','SECTION_ID')
adjustSequence('PERMS','PERMS_SEQ','PERM_ID')
adjustSequence('PERSON_CUST_VALUES','PERSON_CUST_VALUES_SEQ','PERSON_CUST_VALUE_ID')
adjustSequence('PRESENTATION','PRESENTATION_SEQ','PRESENTATION_ID')
adjustSequence('PROCES','PROCES_SEQ','PROC_ID',true,false,true)
adjustSequence('PROPERTY','PROPERTY_SEQ','PROPERTY_ID')
adjustSequence('PROV_PROTS','PROV_PROTS_SEQ','PROV_PROT_ID')
if(!excludeNodeEngineTables) {
    adjustSequence('QCPS','QCPS_SEQ','QCP_ID')
}
adjustSequence('RECIPIENTS','RECIPIENTS_SEQ','RECIPIENT_ID')
adjustSequence('REGIONS','REGIONS_SEQ','REGION_ID')
adjustSequence('RESPONSE_CONFIG','RESPONSE_CONFIG_ID_SEQ','RESPONSE_CONFIG_ID')
adjustSequence('RESRC_CAT','RESRC_CAT_SEQ','RESRC_CAT_ID')
adjustSequence('RESRC_ITEMS','RESRC_ITEMS_SEQ','RESRC_ITEM_ID')
adjustSequence('RESRC_ITEM_DETAIL','RESRC_ITEM_DETAIL_SEQ','RESRC_ITEM_DETAIL_ID')
adjustSequence('RESRC_SETS','RESRC_SETS_SEQ','RESRC_SET_ID')
adjustSequence('RESRC_VALUES','RESRC_VALUES_SEQ','RESRC_VALUE_ID')
adjustSequence('ROLE_PERMS','ROLE_PERMS_SEQ','ROLE_PERM_ID')
adjustSequence('SCENARIO_ATTACHMENTS','SCENARIO_ATTACHMENTS_ID_SEQ','ID')
adjustSequence('SCENS','SCENS_SEQ','SCEN_ID')
adjustSequence('SCEN_INITIATORS','SCEN_INITIATORS_ID_SEQ','SCEN_INIT_ID')
adjustSequence('SCEN_PREDS','SCEN_PREDS_SEQ','SCEN_PRED_ID')
adjustSequence('SCEN_PRED_LIST_VALUES','SCEN_PRED_LIST_VALUES_SEQ','SCEN_PRED_LIST_VALUE_ID')
adjustSequence('SCEN_PRED_TEXT_VALUES','SCEN_PRED_TEXT_VALUES_SEQ','SCEN_PRED_TEXT_VALUE_ID')
adjustSequence('SCEN_RECIPIENTS','SCEN_RECIPIENTS_SEQ','SCEN_RECIPIENT_ID')
adjustSequence('SCEN_RESPONSES','SCEN_RESPONSES_SEQ','SCEN_RESPONSE_ID')
adjustSequence('SCHED_SCENS','SCHED_SCENS_SEQ','SCHED_SCEN_ID')
adjustSequence('SCR_OBJS','SCR_OBJS_SEQ','OBJ_ID',true,false,true)
adjustSequence('SCR_PKGS','SCR_PKGS_SEQ','ID')
adjustSequence('SCR_PKG_VERS','SCR_PKG_VERS_SEQ','ID')
adjustSequence('SCR_VARS','SCR_VARS_SEQ','VAR_ID',true,false,true)
adjustSequence('SCR','SCR_SEQ','ID')
adjustSequence('SCS','SCS_SEQ','CONTXT_ID',true,false,true)
adjustSequence('SC_CALL_STKS','SC_CALL_STKS_SEQ','CALL_ID',true,false,true)
adjustSequence('SC_FOR_STKS','SC_FOR_STKS_SEQ','FOR_ID',true,false,true)
adjustSequence('SC_JUMP_STKS','SC_JUMP_STKS_SEQ','ELEM_ID',true,false,true)
adjustSequence('SEC_AUDIT','SEC_AUDIT_SEQ','SEC_AUDIT_ID')
adjustSequence('SHARED_LISTS','SHARED_LISTS_SEQ','SHARED_LIST_ID')
adjustSequence('SHARED_LIST_VALUES','SHARED_LIST_VALUES_SEQ','SHARED_LIST_VALUE_ID')
adjustSequence('SIMP_SMS_RESPS','SIMP_SMS_RESPS_ID_SEQ','SIMP_SMS_RESPS_ID')
adjustSequence('SIMP_SMS_RESPS_LOCK','SIMP_SMS_RESPS_LOCK_ID_SEQ','SIMP_SMS_RESPS_LOCK_ID')
adjustSequence('SITES','SITES_SEQ','SITE_ID')
adjustSequence('SITE_HOLIDAYS','SITE_HOLIDAYS_SEQ','SITE_HOLIDAY_ID')
adjustSequence('SRCH_CRTA','SRCH_CRTA_SEQ','SRCH_CRTA_ID')
adjustSequence('SRCH_CRTN','SRCH_CRTN_SEQ','SRCH_CRTN_ID')
adjustSequence('STD_ROLES','STD_ROLES_SEQ','STD_ROLE_ID')
adjustSequence('SUBS','SUBS_SEQ','SUB_ID')
adjustSequence('SUB_DMN','SUB_DMN_SEQ','SUB_DMN_ID')
adjustSequence('SUB_PREDS','SUB_PREDS_SEQ','SUB_PRED_ID')
adjustSequence('SUB_TF','SUB_TF_SEQ','SUB_TF_ID')
adjustSequence('TIMING_LOG','TIMING_LOG_SEQ','TIM_EV_ID')
adjustSequence('TMP_RPMT','TMP_RPMT_SEQ','TMP_RPMT_ID')
adjustSequence('TM_TMPLS','TM_TMPLS_SEQ','TM_TMPL_ID')
adjustSequence('TZ','TZ_SEQ','TZ_ID')
adjustSequence('URL_ALIAS','URL_ALIAS_SEQ','URL_ALIAS_ID')
adjustSequence('VOICE_MSGS','VOICE_MSGS_SEQ','VOICE_MSG_ID')
adjustSequence('WEB_HDS','WEB_HDS_SEQ','WEB_HD_ID')
adjustSequence('WEB_HD_MONS','WEB_HD_MONS_SEQ','WEB_HD_MON_ID')
adjustSequence('WS_AUDIT','WS_AUDIT_SEQ','WS_AUDIT_ID')


adjustSequence('ACTIVITY_UPDATES_DEVICE_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ACTIVITY_UPDATES_RECIPIENT_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ACTIVITY_UPDATES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('GRP_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('GRP_SUPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('GRP_TF_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('HOLIDAYS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('IM_DVC_DTL_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('INTR_SVC_ROLES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('MSG_DMN_PREDS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('MSG_DMN_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('MSG_DMN_ROLES_REV','REV_SEQ','REV_SEQ', false, false)
if(!excludeNodeEngineTables) {
    adjustSequence('NODES_REV','REV_SEQ','REV_SEQ', false, false)
    adjustSequence('NODE_COMPONENTS_REV','REV_SEQ','REV_SEQ', false, false)
}
adjustSequence('NUM_PAGE_DVC_DTL_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORGS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_CLUSTERS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_COUNTRIES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_DVC_NAMES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_DVC_TYPES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_FUNC_PERMS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_FUNC_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_HOLIDAYS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_LANGUAGES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_LDAPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_LDAP_TMPLS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_PWD_POLICIES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_QUOTAS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_SVC_PROVS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_SVC_PROV_PROTS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ORG_TZ_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('DVC_NAMES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('DVC_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('DVC_TF_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('DYN_TM_SUPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('EMAIL_DVC_DTL_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ENCODED_LICENSES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('EVS_TML_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('EV_DMN_PRED_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('EV_DMN_PRED_VALUES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('EV_DMN_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('FAST_ACCESS_SCENS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('FAX_DVC_DTL_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('FORM_PERMS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('FUNC_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('GEN_DVC_DTL_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('GRP_OBSERVERS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_HTTPC_PARAMS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_HTTPC_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_HTTPXMCONF_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_HTTPXMSMS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_JABBERS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_MAPIS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_NOTES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_PAGERS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_PHONES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_PUCPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_SIPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_SMPPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_SMPP_TAGS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_SMTPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_SNPPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_SUCPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_TAPLS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_TAPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_UCPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_VDVC_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_WCTPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROV_PROTS_REV','REV_SEQ','REV_SEQ', false, false)
if(!excludeNodeEngineTables) {
    adjustSequence('QCPS_REV','REV_SEQ','REV_SEQ', false, false)
    adjustSequence('QCP_VALUES_REV','REV_SEQ','REV_SEQ', false, false)
}
adjustSequence('RECIPIENTS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SUBS_ORG_DVC_TYPES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SUBS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SUB_MANAGERS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SUB_PREDS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SUB_PRED_VALUES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SUB_RECIPIENTS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SUB_TF_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('TMP_RPMT_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('TM_ESCALATION_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('TM_MBRSHIPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('TM_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('TM_ROTATION_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('TM_TMPLS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('TM_TMPL_ESCALATION_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('TM_TMPL_MBRSHIPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('TXT_PAGE_DVC_DTL_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('TXT_PHONE_DVC_DTL_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('VIRTUAL_DVC_DTL_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('VOC_DVC_DTL_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('WEB_CREDS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('WEB_HDS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ROLE_FUNC_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ROLE_PERMS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ROLE_PERM_GRANTS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ROLE_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SCENS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SCEN_INITIATORS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SCEN_PREDS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SCEN_PRED_LIST_VALUES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SCEN_PRED_TEXT_VALUES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SCEN_RECIPIENTS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SCEN_RESPONSES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SCEN_SUPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SCHED_SCENS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SHARED_LISTS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SHARED_LIST_VALUES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SITES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('SITE_HOLIDAYS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ALERT_GENERATOR_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ALERT_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('APPLE_PUSH_DVC_DTL_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ATTRS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ATTR_CAT_JOIN_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('ATTR_CAT_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('BES_DVC_DTL_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('CLUSTERS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('CUST_ATTR_CAT_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('CUST_FLDS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('DATA_LOCK_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('DATE_RNG_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('DATE_RPT_PATTERNS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('DATE_RULES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('DRNGSS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('DRNGS_RNG_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('DRSS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PERMS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PERSONS_FUNC_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PERSONS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PERSON_ATTRS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PERSON_CUST_VALUES_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PERSON_MSPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PERSON_SUPS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PHONE_CREDS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_APPLEPUSH_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_BESS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_DTMFS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_GENS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_GEN_ARGS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_GSMS_REV','REV_SEQ','REV_SEQ', false, false)
adjustSequence('PROT_HTTPCONF_REV','REV_SEQ','REV_SEQ', false, false)


/**
 * XFO-7536 Update the webservice ACL for denied webservices
 */
updateWebserviceACL()

/**
 * Unmerge accounts as needed
 */
unmergeAccounts()


/*
 * Insert missing(and required) QCP
 */
if(!excludeNodeEngineTables) {
    List<String> columns = ['QCP_KEY']
    List<String> values = ["'ENABLE_PHONE_EXTENSIONS'"]
    if(targetType.toString().equals(DatabaseType.ORACLE) || targetType.toString().equals(DatabaseType.DB2)){
        columns <<  'QCP_ID'
        values <<  'QCPS_SEQ.nextval'
    }
    runSqlOnTarget("insert into QCPS (${columns.join(',')}) values (${values.join(',')})".toString())
    runSqlOnTarget("insert into QCP_VALUES (QCP_ID, QCP_VALUE, POSITION) values ( (SELECT MAX(QCP_ID) FROM QCPS) , 'true', 0)")
}

schema.alterTableTriggersIndexesAndConstraints(true)


return this.timingResults